import numpy as np
import random

def hello_world():
    print("Hello World")
    
def hello_human(name: str):
    print("Hello, " + name)

def numpy_array():
    print("Array:\n" + np.array([16, 4, 2]))